@@ -50,12 +50,14 @@ extern "C" {
 /// Minor library version number
 #define LF_VERSION_MINOR	3
 /// Library micro version number
-#define LF_VERSION_MICRO	2
+#define LF_VERSION_MICRO	3
 /// Library bugfix number
 #define LF_VERSION_BUGFIX	0
 /// Full library version
 #define LF_VERSION	((LF_VERSION_MAJOR << 24) | (LF_VERSION_MINOR << 16) | (LF_VERSION_MICRO << 8) | LF_VERSION_BUGFIX)
 
+/// Oldest database version supported by this release
+#define LF_MIN_DATABASE_VERSION	0
 /// Latest database version supported by this release
 #define LF_MAX_DATABASE_VERSION	1
 
@@ -215,6 +217,11 @@ struct LF_EXPORT lfMount
      */
     lfMount ();
 
+    /**
+     * Copy constructor
+     */
+    lfMount (const lfMount &other);
+
     /**
      * Assignment operator
      */
@@ -786,11 +793,10 @@ C_TYPEDEF (enum, lfLensType)
  * @brief Lens data.
  * Unknown fields are set to NULL or 0.
  *
- * To create a new lens object, use the lfLens::Create() or lf_lens_new()
- * functions. After that fill the fields for which you have data, and
- * invoke the lfLens::Check or lf_lens_check() function, which will
- * check if existing data is enough and will fill some fields using
- * information extracted from lens name.
+ * To manually create a new lens object, fill the fields for which you 
+ * have data, and invoke the lfLens::Check() or lf_lens_check() function, 
+ * which will check if existing data is enough and will automatically fill
+ * some fields using information extracted from lens name.
  */
 struct LF_EXPORT lfLens
 {
@@ -804,7 +810,7 @@ struct LF_EXPORT lfLens
     float MaxFocal;
     /** Smallest f-number possible (ex: 3.5). */
     float MinAperture;
-    /** Biggest f-number possible (ex: 22). Can be equal to MinAperture. */
+    /** Biggest f-number possible (ex: 22). */
     float MaxAperture;
     /** Available mounts (NULL-terminated list) (ex: { "QBM", NULL }) */
     char **Mounts;
@@ -1351,9 +1357,6 @@ enum
  * (see lfDatabase::HomeDataDir), where it will override any definitions
  * from the system-wide database.
  *
- * You cannot create and destroy objects of this type directly; instead
- * use the lf_db_new() / lf_db_destroy() functions or the
- * lfDatabase::Create() / lfDatabase::Destroy() methods.
  */
 struct LF_EXPORT lfDatabase
 {
@@ -1368,20 +1371,24 @@ struct LF_EXPORT lfDatabase
     ~lfDatabase ();
 
     /**
-     * @brief Create a new empty database object.
+     * @brief Create a new empty database object. This function is deprecated and
+     * will be removed in the future. Use the standard constructor instead.
      */
-    static lfDatabase *Create ();
+    DEPRECATED static lfDatabase *Create ();
 
     /**
      * @brief Destroy the database object and free all loaded data.
+     *
+     * This function is deprecated and will be removed in the future. 
+     * Please use the standard destructor instead.
      */
-    void Destroy ();
+    DEPRECATED void Destroy ();
 
     /**
-     * @brief Load all XML files from a directory.
+     * @brief Open and parse all XML files in a given directory.
      *
-     * This is an internal function used by lfDatabase::Load ().  It ignores
-     * all errors.
+     * Returns true if valid Lensfun XML data was found and loaded
+     * sucessfully.
      * @param dirname
      *     The directory to be read.
      * @return
@@ -1392,7 +1399,8 @@ struct LF_EXPORT lfDatabase
     /**
      * @brief Find and load the lens database.
      * 
-     * See @ref dbsearch for more information.
+     * This function automatically tries to determine the location of the 
+     * lens database on the system. See @ref dbsearch for more information.
      * @return
      *     LF_NO_ERROR or a error code.
      */
@@ -1683,6 +1691,9 @@ LF_EXPORT lfError lf_db_load (lfDatabase *db);
 /** @sa lfDatabase::Load(const char *) */
 LF_EXPORT lfError lf_db_load_file (lfDatabase *db, const char *filename);
 
+/** @sa lfDatabase::LoadDirectory(const char *) */
+LF_EXPORT cbool lf_db_load_directory (lfDatabase *db, const char *dirname);
+
 /** @sa lfDatabase::Load(const char *, const char *, size_t) */
 LF_EXPORT lfError lf_db_load_data (lfDatabase *db, const char *errcontext,
                                    const char *data, size_t data_size);
@@ -1898,18 +1909,22 @@ typedef void (*lfModifyColorFunc) (void *data, float x, float y,
 typedef void (*lfModifyCoordFunc) (void *data, float *iocoord, int count);
 
 // @cond
-    
+#ifdef __cplusplus
+
 /// Common ancestor for lfCoordCallbackData and lfColorCallbackData
 struct lfCallbackData
 {
     int priority;
     void *data;
     size_t data_size;
+
+    virtual ~lfCallbackData() {};
 };
 
 // A test point in the autoscale algorithm
 typedef struct { float angle, dist; } lfPoint;
 
+#endif
 // @endcond
 
 /**
@@ -1921,7 +1936,7 @@ typedef struct { float angle, dist; } lfPoint;
  * a lens object, which contains a set of correction models, and
  * create a modifier object from it.
  *
- * Normally, you will create an instance with lfModifier::Create and initilise
+ * Normally, you will create an instance of lfModifier and initialise
  * immediately it with lfModifier::Initialize, passing a valid lens object in
  * both cases.  Users of the plain C interface will use lf_modifier_new() and
  * lf_modifier_initialize() instead.
@@ -1965,7 +1980,9 @@ typedef struct { float angle, dist; } lfPoint;
  * Then, the distortions introduced by the lens are removed (distortion and
  * geometry), and an additional scaling factor is applied if required.  This
  * operation requires building new image in a new allocated buffer: you cannot
- * modify the image in place, or bad things will happen.
+ * modify the image in place, or bad things will happen.  Note that Lensfun
+ * does not provide pixel interpolation routines.  You have to implement the
+ * lookup in the original image yourself.
  *
  * And finally, in the subpixel distortion stage, application corrects
  * transversal chromatic aberrations. For every target pixel coordinate the
@@ -1999,7 +2016,7 @@ struct LF_EXPORT lfModifier
 {
 #ifdef __cplusplus
     /**
-     * @brief Create a empty image modifier object.
+     * @brief Create an empty image modifier object.
      *
      * Before using the returned object you must add the required
      * modifier callbacks (see methods AddXXXCallback below).
@@ -2023,7 +2040,7 @@ struct LF_EXPORT lfModifier
     ~lfModifier ();
 
     /**
-     * @brief Create a empty image modifier object.
+     * @brief Create an empty image modifier object.
      *
      * Before using the returned object you must add the required
      * modifier callbacks (see methods AddXXXCallback below).
@@ -2031,6 +2048,9 @@ struct LF_EXPORT lfModifier
      * You must provide the original image width/height even if you
      * plan to correct just a part of the image.
      *
+     * This function is deprecated and will be removed in the future. 
+     * Please use the standard constructor instead.
+     *
      * @param lens
      *     For all modifications, the crop factor, aspect ratio, and
      *     center shift of this lens will be used.
@@ -2045,7 +2065,7 @@ struct LF_EXPORT lfModifier
      * @return
      *     A new empty image modifier object.
      */
-    static lfModifier *Create (const lfLens *lens, float crop, int width, int height);
+    DEPRECATED static lfModifier *Create (const lfLens *lens, float crop, int width, int height);
 
     /**
      * @brief Initialize the process of correcting aberrations in a image.
@@ -2063,7 +2083,7 @@ struct LF_EXPORT lfModifier
      * @param lens
      *     The lens which aberrations you want to correct in a image.
      *     It should be the same lens object as the one passed to
-     *     lfModifier::Create.
+     *     the lfModifier constructor.
      * @param format
      *     Pixel format of your image (bits per pixel component)
      * @param focal
@@ -2099,9 +2119,10 @@ struct LF_EXPORT lfModifier
     /**
      * @brief Destroy the modifier object.
      *
-     * This is the only correct way to destroy a lfModifier object.
+     * This function is deprecated and will be removed in the future. 
+     * Please use the standard destructor instead.
      */
-    void Destroy ();
+    DEPRECATED void Destroy ();
 
     /**
      * @brief Add a user-defined callback to the coordinate correction chain.
